@@ -6,8 +6,8 @@ val raise_rpc_error : Dune_rpc_private.Response.Error.t -> 'a
 
 (** Make a request and raise an exception if the preperation for the request
     fails in any way. Returns an [Error] if the response errors. *)
-val request_exn :
-     Dune_rpc_client.Client.t
+val request_exn
+  :  Dune_rpc_client.Client.t
   -> ('a, 'b) Dune_rpc_private.Decl.Request.witness
   -> 'a
   -> ('b, Dune_rpc_private.Response.Error.t) result Fiber.t
