@@ -8,11 +8,14 @@ module String_with_vars = String_with_vars
 module Pform = Pform
 module Action = Action
 module Dune_file_script = Dune_file_script
+module Path = Path
 module Value = Value
 module Blang = Blang
 module Binary_kind = Binary_kind
 module Package_constraint = Package_constraint
 module Package_name = Package_name
+module Lib_kind = Lib_kind
+module Lib_dep = Lib_dep
 module Pkg = Pkg
 module Ordered_set_lang = Ordered_set_lang
 module Format_config = Format_config
@@ -22,3 +25,5 @@ module Locks = Locks
 module Profile = Profile
 module Targets_spec = Targets_spec
 module Wrapped = Wrapped
+module Visibility = Visibility
+module Dep_conf = Dep_conf
