@@ -4,6 +4,9 @@ module Lock_dir = Lock_dir
 module Opam_file = Opam_file
 module Opam_repo = Opam_repo
 module Opam_solver = Opam_solver
+module Package_variable = Package_variable
+module Repository_id = Repository_id
 module Solver_env = Solver_env
+module Substs = Substs
 module Sys_poll = Sys_poll
 module Version_preference = Version_preference
