@@ -1,5 +1,4 @@
 (** Cinaps integration *)
-open! Dune_engine
 
 (** Cinaps is a small tool that allows to auto-generate part of ml or other
     source files and keep them in sync:
@@ -9,12 +8,10 @@ open! Dune_engine
     This module implements the [cinaps] stanza that integrate cinaps nicely with
     dune. *)
 
-open Stdune
+open Import
 
 type t
-
 type Stanza.t += T of t
 
 (** Generate the rules to handle this cinaps stanza *)
-val gen_rules :
-  Super_context.t -> t -> dir:Path.Build.t -> scope:Scope.t -> unit
+val gen_rules : Super_context.t -> t -> dir:Path.Build.t -> scope:Scope.t -> unit Memo.t
