@@ -29,7 +29,6 @@ module Args0 = struct
     | Expand : expand -> _ t
 
   let dyn args = Dyn (Action_builder.map args ~f:(fun x -> As x))
-
   let empty = S []
 
   let rec as_any : without_targets t -> any t = function
@@ -45,25 +44,25 @@ module Args0 = struct
     | Dyn _ as x -> (x :> any t)
     | Fail _ as x -> (x :> any t)
     | Expand _ as x -> (x :> any t)
+  ;;
 end
 
 open Args0
 
-let rec expand :
-    type a. dir:Path.t -> a t -> string list Action_builder.With_targets.t =
- fun ~dir t ->
+let rec expand : type a. dir:Path.t -> a t -> string list Action_builder.With_targets.t =
+  fun ~dir t ->
   match t with
   | A s -> Action_builder.With_targets.return [ s ]
   | As l -> Action_builder.With_targets.return l
   | Dep fn ->
     Action_builder.with_no_targets
       (Action_builder.map (Action_builder.path fn) ~f:(fun () ->
-           [ Path.reach fn ~from:dir ]))
+         [ Path.reach fn ~from:dir ]))
   | Path fn -> Action_builder.With_targets.return [ Path.reach fn ~from:dir ]
   | Deps fns ->
     Action_builder.with_no_targets
       (Action_builder.map (Action_builder.paths fns) ~f:(fun () ->
-           List.map fns ~f:(Path.reach ~from:dir)))
+         List.map fns ~f:(Path.reach ~from:dir)))
   | Paths fns ->
     Action_builder.With_targets.return (List.map fns ~f:(Path.reach ~from:dir))
   | S ts ->
@@ -72,9 +71,10 @@ let rec expand :
       ~f:List.concat
   | Concat (sep, ts) ->
     Action_builder.With_targets.map (expand ~dir (S ts)) ~f:(fun x ->
-        [ String.concat ~sep x ])
+      [ String.concat ~sep x ])
   | Target fn ->
-    Action_builder.with_file_targets ~file_targets:[ fn ]
+    Action_builder.with_file_targets
+      ~file_targets:[ fn ]
       (Action_builder.return [ Path.reach (Path.build fn) ~from:dir ])
   | Dyn dyn ->
     Action_builder.with_no_targets
@@ -84,21 +84,23 @@ let rec expand :
     Action_builder.with_no_targets
       (Action_builder.map (Action_builder.deps deps) ~f:(fun () -> []))
   | Hidden_targets fns ->
-    Action_builder.with_file_targets ~file_targets:fns
-      (Action_builder.return [])
+    Action_builder.with_file_targets ~file_targets:fns (Action_builder.return [])
   | Expand f -> Action_builder.with_no_targets (f ~dir)
 
 and expand_no_targets ~dir (t : without_targets t) =
   let { Action_builder.With_targets.build; targets } = expand ~dir t in
   assert (Targets.is_empty targets);
   build
+;;
 
 let dep_prog = function
   | Ok p -> Action_builder.path p
   | Error _ -> Action_builder.return ()
+;;
 
 let run ~dir ?sandbox ?stdout_to prog args =
-  Action_builder.With_targets.add ~file_targets:(Option.to_list stdout_to)
+  Action_builder.With_targets.add
+    ~file_targets:(Option.to_list stdout_to)
     (let open Action_builder.With_targets.O in
      let+ () = Action_builder.with_no_targets (dep_prog prog)
      and+ args = expand ~dir (S args) in
@@ -109,12 +111,14 @@ let run ~dir ?sandbox ?stdout_to prog args =
        | Some path -> Action.with_stdout_to path action
      in
      Action.Full.make ?sandbox (Action.chdir dir action))
+;;
 
 let run' ~dir prog args =
   let open Action_builder.O in
   let+ () = dep_prog prog
   and+ args = expand_no_targets ~dir (S args) in
   Action.Full.make (Action.chdir dir (Action.run prog args))
+;;
 
 let quote_args =
   let rec loop quote = function
@@ -122,6 +126,7 @@ let quote_args =
     | arg :: args -> quote :: arg :: loop quote args
   in
   fun quote args -> As (loop quote args)
+;;
 
 let fail e = Fail { fail = (fun _ -> raise e) }
 
@@ -130,17 +135,17 @@ module Args = struct
 
   let memo t =
     let memo =
-      Action_builder.create_memo "Command.Args.memo"
+      Action_builder.create_memo
+        "Command.Args.memo"
         ~input:(module Path)
         ~cutoff:(List.equal String.equal)
         (fun dir -> expand_no_targets ~dir t)
     in
     Expand (fun ~dir -> Action_builder.exec_memo memo dir)
+  ;;
 end
 
 module Ml_kind = struct
   let flag t = Ml_kind.choose ~impl:(Args.A "-impl") ~intf:(A "-intf") t
-
-  let ppx_driver_flag t =
-    Ml_kind.choose ~impl:(Args.A "--impl") ~intf:(A "--intf") t
+  let ppx_driver_flag t = Ml_kind.choose ~impl:(Args.A "--impl") ~intf:(A "--intf") t
 end
