@@ -16,8 +16,8 @@ end
 
 type t
 
-val make :
-     Build_context.t
+val make
+  :  Build_context.t
   -> dir:Path.Build.t
   -> inherit_from:t Memo.Lazy.t option
   -> scope:Scope.t
@@ -32,31 +32,17 @@ val make :
   -> t
 
 val scope : t -> Scope.t
-
 val external_env : t -> Env.t Memo.t
-
 val ocaml_flags : t -> Ocaml_flags.t Memo.t
-
 val inline_tests : t -> Dune_env.Stanza.Inline_tests.t Memo.t
-
 val js_of_ocaml : t -> string list Action_builder.t Js_of_ocaml.Env.t Memo.t
-
 val foreign_flags : t -> string list Action_builder.t Foreign_language.Dict.t
-
 val link_flags : t -> Link_flags.t Memo.t
-
 val local_binaries : t -> File_binding.Expanded.t list Memo.t
-
 val bin_artifacts : t -> Artifacts.Bin.t Memo.t
-
 val odoc : t -> Odoc.t Memo.t
-
 val coq : t -> Coq.t Action_builder.t Memo.t
-
 val menhir_flags : t -> string list Action_builder.t
-
 val format_config : t -> Format_config.t Memo.t
-
 val set_format_config : t -> Format_config.t -> t
-
 val bin_annot : t -> bool Memo.t
