@@ -10,14 +10,14 @@ module File : sig
 
   val decode : t Dune_lang.Decoder.t
 
-  val to_file_bindings_unexpanded :
-       t list
+  val to_file_bindings_unexpanded
+    :  t list
     -> expand_str:(String_with_vars.t -> string Memo.t)
     -> dir:Path.Build.t
     -> File_binding.Unexpanded.t list Memo.t
 
-  val to_file_bindings_expanded :
-       t list
+  val to_file_bindings_expanded
+    :  t list
     -> expand_str:(String_with_vars.t -> string Memo.t)
     -> dir:Path.Build.t
     -> File_binding.Expanded.t list Memo.t
@@ -32,9 +32,11 @@ module Dir : sig
 
   val decode : t Dune_lang.Decoder.t
 
-  val to_file_bindings_expanded :
-       t list
+  val to_file_bindings_expanded
+    :  t list
     -> expand_str:(String_with_vars.t -> string Memo.t)
     -> dir:Path.Build.t
+    -> relative_dst_path_starts_with_parent_error_when:
+         [ `Deprecation_warning_from_3_11 | `Always_error ]
     -> File_binding.Expanded.t list Memo.t
 end
