@@ -4,6 +4,7 @@ let remove_extension file =
   let dir = Path.Build.parent_exn file in
   let basename, _ext = String.lsplit2_exn (Path.Build.basename file) ~on:'.' in
   Path.Build.relative dir basename
+;;
 
 module Processed = struct
   (* The actual content of the merlin file as built by the [Unprocessed.process]
@@ -22,10 +23,12 @@ module Processed = struct
       function
       | Pp -> variant "Pp" []
       | Ppx -> variant "Ppx" []
+    ;;
 
     let to_flag = function
       | Pp -> "-pp"
       | Ppx -> "-ppx"
+    ;;
   end
 
   type pp_flag =
@@ -35,10 +38,10 @@ module Processed = struct
 
   let dyn_of_pp_flag { flag; args } =
     let open Dyn in
-    record [ ("flag", Pp_kind.to_dyn flag); ("args", string args) ]
+    record [ "flag", Pp_kind.to_dyn flag; "args", string args ]
+  ;;
 
   let pp_kind x = x.flag
-
   let pp_args x = x.args
 
   (* Most of the configuration is shared across a same lib/exe... *)
@@ -51,17 +54,17 @@ module Processed = struct
     ; melc_flags : string list
     }
 
-  let dyn_of_config
-      { stdlib_dir; obj_dirs; src_dirs; flags; extensions; melc_flags } =
+  let dyn_of_config { stdlib_dir; obj_dirs; src_dirs; flags; extensions; melc_flags } =
     let open Dyn in
     record
-      [ ("stdlib_dir", option Path.to_dyn stdlib_dir)
-      ; ("obj_dirs", Path.Set.to_dyn obj_dirs)
-      ; ("src_dirs", Path.Set.to_dyn src_dirs)
-      ; ("flags", list string flags)
-      ; ("extensions", list (Ml_kind.Dict.to_dyn (Dyn.option string)) extensions)
-      ; ("melc_flags", list string melc_flags)
+      [ "stdlib_dir", option Path.to_dyn stdlib_dir
+      ; "obj_dirs", Path.Set.to_dyn obj_dirs
+      ; "src_dirs", Path.Set.to_dyn src_dirs
+      ; "flags", list string flags
+      ; "extensions", list (Ml_kind.Dict.to_dyn (Dyn.option string)) extensions
+      ; "melc_flags", list string melc_flags
       ]
+  ;;
 
   type module_config =
     { opens : Module_name.t list
@@ -70,10 +73,8 @@ module Processed = struct
 
   let dyn_of_module_config { opens; module_ } =
     let open Dyn in
-    record
-      [ ("opens", list Module_name.to_dyn opens)
-      ; ("module_", Module.to_dyn module_)
-      ]
+    record [ "opens", list Module_name.to_dyn opens; "module_", Module.to_dyn module_ ]
+  ;;
 
   (* ...but modules can have different preprocessing specifications*)
   type t =
@@ -85,20 +86,17 @@ module Processed = struct
   let to_dyn { config; per_module_config; pp_config } =
     let open Dyn in
     record
-      [ ("config", dyn_of_config config)
-      ; ( "per_module_config"
-        , Path.Build.Map.to_dyn dyn_of_module_config per_module_config )
-      ; ( "pp_config"
-        , Module_name.Per_item.to_dyn (option dyn_of_pp_flag) pp_config )
+      [ "config", dyn_of_config config
+      ; "per_module_config", Path.Build.Map.to_dyn dyn_of_module_config per_module_config
+      ; "pp_config", Module_name.Per_item.to_dyn (option dyn_of_pp_flag) pp_config
       ]
+  ;;
 
   module D = struct
     type nonrec t = t
 
     let name = "merlin-conf"
-
     let version = 4
-
     let to_dyn _ = Dyn.String "Use [dune ocaml dump-dot-merlin] instead"
 
     let test_example () =
@@ -114,14 +112,13 @@ module Processed = struct
       ; pp_config =
           (match
              Module_name.Per_item.of_mapping
-               [ ( [ Module_name.of_string "Test" ]
-                 , Some { flag = Ppx; args = "-x" } )
-               ]
+               [ [ Module_name.of_string "Test" ], Some { flag = Ppx; args = "-x" } ]
                ~default:None
            with
-          | Ok s -> s
-          | Error (_, _, _) -> assert false)
+           | Ok s -> s
+           | Error (_, _, _) -> assert false)
       }
+    ;;
   end
 
   module Persist = Dune_util.Persistent.Make (D)
@@ -134,21 +131,23 @@ module Processed = struct
     | Some s -> Ok s
     | None ->
       Error
-        "The current Merlin configuration has been generated by another, \
-         incompatible, version of Dune. Please rebuild the project. (Using the \
-         same version of Dune as the one running the `ocaml-merlin` server.)"
+        "The current Merlin configuration has been generated by another, incompatible, \
+         version of Dune. Please rebuild the project. (Using the same version of Dune as \
+         the one running the `ocaml-merlin` server.)"
+  ;;
 
   let serialize_path = Path.to_absolute_filename
 
   let get_ext { Ml_kind.Dict.impl; intf } =
-    match (impl, intf) with
+    match impl, intf with
     | Some impl, Some intf -> Some (impl, intf)
     | Some impl, None -> Some (impl, impl)
     | None, Some intf -> Some (intf, intf)
     | None, None -> None
+  ;;
 
-  let to_sexp ~opens ~pp
-      { stdlib_dir; obj_dirs; src_dirs; flags; extensions; melc_flags } =
+  let to_sexp ~opens ~pp { stdlib_dir; obj_dirs; src_dirs; flags; extensions; melc_flags }
+    =
     let make_directive tag value = Sexp.List [ Atom tag; value ] in
     let make_directive_of_path tag path =
       make_directive tag (Sexp.Atom (serialize_path path))
@@ -159,59 +158,53 @@ module Processed = struct
       | Some stdlib_dir -> [ make_directive_of_path "STDLIB" stdlib_dir ]
     in
     let exclude_query_dir = [ Sexp.List [ Atom "EXCLUDE_QUERY_DIR" ] ] in
-    let obj_dirs =
-      Path.Set.to_list_map obj_dirs ~f:(make_directive_of_path "B")
-    in
-    let src_dirs =
-      Path.Set.to_list_map src_dirs ~f:(make_directive_of_path "S")
-    in
+    let obj_dirs = Path.Set.to_list_map obj_dirs ~f:(make_directive_of_path "B") in
+    let src_dirs = Path.Set.to_list_map src_dirs ~f:(make_directive_of_path "S") in
     let flags =
       let flags =
         match flags with
         | [] -> []
         | flags ->
-          [ make_directive "FLG"
-              (Sexp.List (List.map ~f:(fun s -> Sexp.Atom s) flags))
-          ]
+          [ make_directive "FLG" (Sexp.List (List.map ~f:(fun s -> Sexp.Atom s) flags)) ]
       in
       let flags =
         match melc_flags with
         | [] -> flags
         | melc_flags ->
-          make_directive "FLG"
-            (Sexp.List (List.map ~f:(fun s -> Sexp.Atom s) melc_flags))
+          make_directive "FLG" (Sexp.List (List.map ~f:(fun s -> Sexp.Atom s) melc_flags))
           :: flags
       in
       let flags =
         match pp with
         | None -> flags
         | Some { flag; args } ->
-          make_directive "FLG"
-            (Sexp.List [ Atom (Pp_kind.to_flag flag); Atom args ])
+          make_directive "FLG" (Sexp.List [ Atom (Pp_kind.to_flag flag); Atom args ])
           :: flags
       in
       match opens with
       | [] -> flags
       | opens ->
-        make_directive "FLG"
+        make_directive
+          "FLG"
           (Sexp.List
              (List.concat_map opens ~f:(fun name ->
-                  [ Sexp.Atom "-open"; Atom (Module_name.to_string name) ])))
+                [ Sexp.Atom "-open"; Atom (Module_name.to_string name) ])))
         :: flags
     in
     let suffixes =
       List.filter_map extensions ~f:(fun x ->
-          let open Option.O in
-          let+ impl, intf = get_ext x in
-          make_directive "SUFFIX" (Sexp.Atom (Printf.sprintf "%s %s" impl intf)))
+        let open Option.O in
+        let+ impl, intf = get_ext x in
+        make_directive "SUFFIX" (Sexp.Atom (Printf.sprintf "%s %s" impl intf)))
     in
     Sexp.List
-      (List.concat
-         [ stdlib_dir; exclude_query_dir; obj_dirs; src_dirs; flags; suffixes ])
+      (List.concat [ stdlib_dir; exclude_query_dir; obj_dirs; src_dirs; flags; suffixes ])
+  ;;
 
   let quote_for_dot_merlin s =
     let s =
-      if Sys.win32 then
+      if Sys.win32
+      then
         (* We need this hack because merlin unescapes backslashes (except when
            protected by single quotes). It is only a problem on windows because
            Filename.quote is using double quotes. *)
@@ -219,6 +212,7 @@ module Processed = struct
       else s
     in
     if String.need_quoting s then Filename.quote s else s
+  ;;
 
   let to_dot_merlin stdlib_dir pp_configs flags obj_dirs src_dirs extensions =
     let b = Buffer.create 256 in
@@ -226,27 +220,28 @@ module Processed = struct
     let print = Buffer.add_string b in
     print "EXCLUDE_QUERY_DIR\n";
     Option.iter stdlib_dir ~f:(fun stdlib_dir ->
-        printf "STDLIB %s\n" (serialize_path stdlib_dir));
+      printf "STDLIB %s\n" (serialize_path stdlib_dir));
     Path.Set.iter obj_dirs ~f:(fun p -> printf "B %s\n" (serialize_path p));
     Path.Set.iter src_dirs ~f:(fun p -> printf "S %s\n" (serialize_path p));
     List.iter extensions ~f:(fun x ->
-        Option.iter (get_ext x) ~f:(fun (impl, intf) ->
-            printf "SUFFIX %s" (Printf.sprintf "%s %s" impl intf)));
+      Option.iter (get_ext x) ~f:(fun (impl, intf) ->
+        printf "SUFFIX %s" (Printf.sprintf "%s %s" impl intf)));
     (* We print all FLG directives as comments *)
-    List.iter pp_configs
+    List.iter
+      pp_configs
       ~f:
         (Module_name.Per_item.fold ~init:() ~f:(fun pp () ->
-             Option.iter pp ~f:(fun { flag; args } ->
-                 printf "# FLG %s\n"
-                   (Pp_kind.to_flag flag ^ " " ^ quote_for_dot_merlin args))));
+           Option.iter pp ~f:(fun { flag; args } ->
+             printf "# FLG %s\n" (Pp_kind.to_flag flag ^ " " ^ quote_for_dot_merlin args))));
     List.iter flags ~f:(fun flags ->
-        match flags with
-        | [] -> ()
-        | flags ->
-          print "# FLG";
-          List.iter flags ~f:(fun f -> printf " %s" (quote_for_dot_merlin f));
-          print "\n");
+      match flags with
+      | [] -> ()
+      | flags ->
+        print "# FLG";
+        List.iter flags ~f:(fun f -> printf " %s" (quote_for_dot_merlin f));
+        print "\n");
     Buffer.contents b
+  ;;
 
   let get { per_module_config; pp_config; config } ~file =
     (* We only match the first part of the filename : foo.ml -> foo foo.cppo.ml
@@ -263,6 +258,7 @@ module Processed = struct
     in
     let pp = Module_name.Per_item.get pp_config (Module.name module_) in
     to_sexp ~opens ~pp config
+  ;;
 
   let print_file path =
     match load_file path with
@@ -283,6 +279,7 @@ module Processed = struct
         |> Pp.vbox
       in
       Format.printf "%a@." Pp.to_fmt pp
+  ;;
 
   let print_generic_dot_merlin paths =
     match Result.List.map paths ~f:load_file with
@@ -291,7 +288,8 @@ module Processed = struct
     | Ok (init :: tl) ->
       let pp_configs, obj_dirs, src_dirs, flags, extensions, melc_flags =
         (* We merge what is easy to merge and ignore the rest *)
-        List.fold_left tl
+        List.fold_left
+          tl
           ~init:
             ( [ init.pp_config ]
             , init.config.obj_dirs
@@ -299,20 +297,15 @@ module Processed = struct
             , [ init.config.flags ]
             , init.config.extensions
             , init.config.melc_flags )
-          ~f:(fun
-               (acc_pp, acc_obj, acc_src, acc_flags, acc_ext, acc_melc_flags)
-               { per_module_config = _
-               ; pp_config
-               ; config =
-                   { stdlib_dir = _
-                   ; obj_dirs
-                   ; src_dirs
-                   ; flags
-                   ; extensions
-                   ; melc_flags
-                   }
-               }
-             ->
+          ~f:
+            (fun
+              (acc_pp, acc_obj, acc_src, acc_flags, acc_ext, acc_melc_flags)
+              { per_module_config = _
+              ; pp_config
+              ; config =
+                  { stdlib_dir = _; obj_dirs; src_dirs; flags; extensions; melc_flags }
+              }
+            ->
             ( pp_config :: acc_pp
             , Path.Set.union acc_obj obj_dirs
             , Path.Set.union acc_src src_dirs
@@ -327,18 +320,26 @@ module Processed = struct
         | [] -> flags
         | melc -> melc :: flags
       in
-      Printf.printf "%s\n"
-        (to_dot_merlin init.config.stdlib_dir pp_configs flags obj_dirs src_dirs
+      Printf.printf
+        "%s\n"
+        (to_dot_merlin
+           init.config.stdlib_dir
+           pp_configs
+           flags
+           obj_dirs
+           src_dirs
            extensions)
+  ;;
 end
 
 let obj_dir_of_lib kind mode obj_dir =
-  (match (kind, mode) with
-  | `Private, Lib_mode.Ocaml _ -> Obj_dir.byte_dir
-  | `Private, Melange -> Obj_dir.melange_dir
-  | `Public, Ocaml _ -> Obj_dir.public_cmi_ocaml_dir
-  | `Public, Melange -> Obj_dir.public_cmi_melange_dir)
+  (match kind, mode with
+   | `Private, Lib_mode.Ocaml _ -> Obj_dir.byte_dir
+   | `Private, Melange -> Obj_dir.melange_dir
+   | `Public, Ocaml _ -> Obj_dir.public_cmi_ocaml_dir
+   | `Public, Melange -> Obj_dir.public_cmi_melange_dir)
     obj_dir
+;;
 
 module Unprocessed = struct
   (* We store separate information for each "module". These information do not
@@ -364,8 +365,19 @@ module Unprocessed = struct
     ; modules : Modules.t
     }
 
-  let make ~requires ~stdlib_dir ~flags ~preprocess ~libname ~source_dirs
-      ~modules ~obj_dir ~dialects ~ident ~modes =
+  let make
+    ~requires
+    ~stdlib_dir
+    ~flags
+    ~preprocess
+    ~libname
+    ~source_dirs
+    ~modules
+    ~obj_dir
+    ~dialects
+    ~ident
+    ~modes
+    =
     (* Merlin shouldn't cause the build to fail, so we just ignore errors *)
     let mode =
       match modes with
@@ -379,8 +391,7 @@ module Unprocessed = struct
       | Error () -> Lib.Set.empty
     in
     let objs_dirs =
-      Path.Set.singleton
-      @@ obj_dir_of_lib `Private mode (Obj_dir.of_local obj_dir)
+      Path.Set.singleton @@ obj_dir_of_lib `Private mode (Obj_dir.of_local obj_dir)
     in
     let flags = Ocaml_flags.get flags mode in
     let extensions = Dialect.DB.extensions_for_merlin dialects in
@@ -397,57 +408,65 @@ module Unprocessed = struct
       }
     in
     { ident; config; modules }
+  ;;
 
   let encode_command =
-    let quote_if_needed s =
-      if String.need_quoting s then Filename.quote s else s
-    in
+    let quote_if_needed s = if String.need_quoting s then Filename.quote s else s in
     fun ~bin ~args ->
       Path.to_absolute_filename bin :: args
       |> List.map ~f:quote_if_needed
       |> String.concat ~sep:" "
+  ;;
 
-  let pp_flag_of_action ~expander ~loc ~action :
-      Processed.pp_flag option Action_builder.t =
+  let pp_flag_of_action ~expander ~loc ~action : Processed.pp_flag option Action_builder.t
+    =
     match (action : Dune_lang.Action.t) with
-    | Run (exe, args) -> (
-      match
-        let open Option.O in
-        let* args, input_file = List.destruct_last args in
-        if String_with_vars.is_pform input_file (Var Input_file) then Some args
-        else None
-      with
-      | None -> Action_builder.return None
-      | Some args ->
-        let action =
-          let action = Action_unexpanded.Run (exe, args) in
-          let chdir = (Expander.context expander).build_dir in
-          Action_unexpanded.expand_no_targets ~loc ~expander ~deps:[] ~chdir
-            ~what:"preprocessing actions" action
-        in
-        let pp_of_action exe args =
-          match exe with
-          | Error _ -> None
-          | Ok bin ->
-            let args =
-              let args = Array.Immutable.to_list args in
-              encode_command ~bin ~args
-            in
-            Some { Processed.flag = Processed.Pp_kind.Pp; args }
-        in
-        Action_builder.map action ~f:(fun act ->
-            match act.action with
-            | Run (exe, args) -> pp_of_action exe args
-            | Chdir (_, Run (exe, args)) -> pp_of_action exe args
-            | Chdir (_, Chdir (_, Run (exe, args))) -> pp_of_action exe args
-            | _ -> None))
+    | Run (exe, args) ->
+      (match
+         let open Option.O in
+         let* args, input_file = List.destruct_last args in
+         if String_with_vars.is_pform input_file (Var Input_file) then Some args else None
+       with
+       | None -> Action_builder.return None
+       | Some args ->
+         let action =
+           let action = Action_unexpanded.Run (exe, args) in
+           let chdir = Expander.context expander |> Context.build_dir in
+           Action_unexpanded.expand_no_targets
+             ~loc
+             ~expander
+             ~deps:[]
+             ~chdir
+             ~what:"preprocessing actions"
+             action
+         in
+         let pp_of_action exe args =
+           match exe with
+           | Error _ -> None
+           | Ok bin ->
+             let args =
+               let args = Array.Immutable.to_list args in
+               encode_command ~bin ~args
+             in
+             Some { Processed.flag = Processed.Pp_kind.Pp; args }
+         in
+         Action_builder.map action ~f:(fun act ->
+           match act.action with
+           | Run (exe, args) -> pp_of_action exe args
+           | Chdir (_, Run (exe, args)) -> pp_of_action exe args
+           | Chdir (_, Chdir (_, Run (exe, args))) -> pp_of_action exe args
+           | _ -> None))
     | _ -> Action_builder.return None
+  ;;
 
-  let pp_flags sctx ~expander lib_name preprocess :
-      Processed.pp_flag option Action_builder.t =
+  let pp_flags sctx ~expander lib_name preprocess
+    : Processed.pp_flag option Action_builder.t
+    =
     match
-      Preprocess.remove_future_syntax preprocess ~for_:Merlin
-        (Super_context.context sctx).ocaml.version
+      Preprocess.remove_future_syntax
+        preprocess
+        ~for_:Merlin
+        (Super_context.context sctx |> Context.ocaml).version
     with
     | Action (loc, (action : Dune_lang.Action.t)) ->
       pp_flag_of_action ~expander ~loc ~action
@@ -456,13 +475,11 @@ module Unprocessed = struct
       let open Action_builder.O in
       let+ exe, flags =
         let scope = Expander.scope expander in
-        Preprocessing.get_ppx_driver sctx ~loc ~expander ~lib_name ~flags ~scope
-          pps
-      in
-      let args =
-        encode_command ~bin:(Path.build exe) ~args:("--as-ppx" :: flags)
+        Preprocessing.get_ppx_driver sctx ~loc ~expander ~lib_name ~flags ~scope pps
       in
+      let args = encode_command ~bin:(Path.build exe) ~args:("--as-ppx" :: flags) in
       Some { Processed.flag = Processed.Pp_kind.Ppx; args }
+  ;;
 
   let src_dirs sctx lib =
     let info = Lib.info lib in
@@ -475,31 +492,38 @@ module Unprocessed = struct
       let open Memo.O in
       let+ modules = Dir_contents.modules_of_lib sctx lib in
       let modules = Option.value_exn modules in
-      Path.Set.map ~f:Path.drop_optional_build_context
-        (Modules.source_dirs modules)
+      Path.Set.map ~f:Path.drop_optional_build_context (Modules.source_dirs modules)
+  ;;
 
   module Per_item_action_builder =
     Module_name.Per_item.Make_monad_traversals (Action_builder)
 
   let pp_config t sctx ~expander =
-    Per_item_action_builder.map t.config.preprocess
+    Per_item_action_builder.map
+      t.config.preprocess
       ~f:(pp_flags sctx ~expander t.config.libname)
+  ;;
 
   let process
-      ({ modules
-       ; ident = _
-       ; config =
-           { stdlib_dir
-           ; extensions
-           ; flags
-           ; objs_dirs
-           ; source_dirs
-           ; requires
-           ; preprocess = _
-           ; libname = _
-           ; mode
-           }
-       } as t) sctx ~dir ~more_src_dirs ~expander =
+    ({ modules
+     ; ident = _
+     ; config =
+         { stdlib_dir
+         ; extensions
+         ; flags
+         ; objs_dirs
+         ; source_dirs
+         ; requires
+         ; preprocess = _
+         ; libname = _
+         ; mode
+         }
+     } as t)
+    sctx
+    ~dir
+    ~more_src_dirs
+    ~expander
+    =
     let open Action_builder.O in
     let+ config =
       let* stdlib_dir =
@@ -507,12 +531,12 @@ module Unprocessed = struct
         @@
         match t.config.mode with
         | Ocaml _ -> Memo.return (Some stdlib_dir)
-        | Melange -> (
+        | Melange ->
           let open Memo.O in
           let+ dirs = Melange_binary.where sctx ~loc:None ~dir in
-          match dirs with
-          | [] -> None
-          | stdlib_dir :: _ -> Some stdlib_dir)
+          (match dirs with
+           | [] -> None
+           | stdlib_dir :: _ -> Some stdlib_dir)
       in
       let* requires =
         match t.config.mode with
@@ -522,13 +546,16 @@ module Unprocessed = struct
             (let open Memo.O in
              let scope = Expander.scope expander in
              let libs = Scope.libs scope in
-             Lib.DB.find libs (Lib_name.of_string "melange") >>= function
+             Lib.DB.find libs (Lib_name.of_string "melange")
+             >>= function
              | Some lib ->
                let+ libs =
                  let linking =
                    Dune_project.implicit_transitive_deps (Scope.project scope)
                  in
-                 Lib.closure [ lib ] ~linking |> Resolve.Memo.peek >>| function
+                 Lib.closure [ lib ] ~linking
+                 |> Resolve.Memo.peek
+                 >>| function
                  | Ok libs -> libs
                  | Error _ -> []
                in
@@ -540,8 +567,8 @@ module Unprocessed = struct
         Action_builder.of_memo
           (let open Memo.O in
            Memo.parallel_map (Lib.Set.to_list requires) ~f:(fun lib ->
-               let+ dirs = src_dirs sctx lib in
-               (lib, dirs))
+             let+ dirs = src_dirs sctx lib in
+             lib, dirs)
            >>| List.fold_left
                  ~init:(Path.set_of_source_paths source_dirs, objs_dirs)
                  ~f:(fun (src_dirs, obj_dirs) (lib, more_src_dirs) ->
@@ -553,55 +580,47 @@ module Unprocessed = struct
                      Path.Set.add obj_dirs public_cmi_dir )))
       in
       let src_dirs =
-        Path.Set.union src_dirs
-          (Path.Set.of_list_map ~f:Path.source more_src_dirs)
+        Path.Set.union src_dirs (Path.Set.of_list_map ~f:Path.source more_src_dirs)
       in
       let+ melc_flags =
         match t.config.mode with
         | Ocaml _ -> Action_builder.return []
-        | Melange -> (
+        | Melange ->
           let+ melc_compiler =
             Action_builder.of_memo (Melange_binary.melc sctx ~loc:None ~dir)
           in
-          match melc_compiler with
-          | Error _ -> []
-          | Ok path ->
-            [ Processed.Pp_kind.to_flag Ppx
-            ; Processed.serialize_path path ^ " -as-ppx"
-            ])
+          (match melc_compiler with
+           | Error _ -> []
+           | Ok path ->
+             [ Processed.Pp_kind.to_flag Ppx; Processed.serialize_path path ^ " -as-ppx" ])
       in
-      { Processed.stdlib_dir
-      ; src_dirs
-      ; obj_dirs
-      ; flags
-      ; extensions
-      ; melc_flags
-      }
+      { Processed.stdlib_dir; src_dirs; obj_dirs; flags; extensions; melc_flags }
     and+ pp_config = pp_config t sctx ~expander in
     let per_module_config =
       (* And copy for each module the resulting pp flags *)
       Modules.fold_no_vlib modules ~init:[] ~f:(fun m init ->
-          Module.sources m
-          |> Path.Build.Set.of_list_map ~f:(fun src ->
-                 Path.as_in_build_dir_exn src |> remove_extension)
-          |> Path.Build.Set.fold ~init ~f:(fun src acc ->
-                 let config =
-                   { Processed.module_ = Module.set_pp m None
-                   ; opens =
-                       Modules.alias_for modules m |> List.map ~f:Module.name
-                   }
-                 in
-                 (src, config) :: acc))
+        Module.sources m
+        |> Path.Build.Set.of_list_map ~f:(fun src ->
+          Path.as_in_build_dir_exn src |> remove_extension)
+        |> Path.Build.Set.fold ~init ~f:(fun src acc ->
+          let config =
+            { Processed.module_ = Module.set_pp m None
+            ; opens = Modules.alias_for modules m |> List.map ~f:Module.name
+            }
+          in
+          (src, config) :: acc))
       |> Path.Build.Map.of_list_exn
     in
     { Processed.pp_config; config; per_module_config }
+  ;;
 end
 
 let dot_merlin sctx ~dir ~more_src_dirs ~expander (t : Unprocessed.t) =
   let open Memo.O in
   let merlin_file = Merlin_ident.merlin_file_path dir t.ident in
   let* () =
-    Rules.Produce.Alias.add_deps (Alias.check ~dir)
+    Rules.Produce.Alias.add_deps
+      (Alias.make Alias0.check ~dir)
       (Action_builder.path (Path.build merlin_file))
   in
   let action =
@@ -611,17 +630,20 @@ let dot_merlin sctx ~dir ~more_src_dirs ~expander (t : Unprocessed.t) =
     |> Action_builder.With_targets.write_file_dyn merlin_file
   in
   Super_context.add_rule sctx ~dir action
+;;
 
 let add_rules sctx ~dir ~more_src_dirs ~expander merlin =
-  Memo.when_ (Super_context.context sctx).merlin (fun () ->
-      dot_merlin sctx ~more_src_dirs ~expander ~dir merlin)
+  Memo.when_
+    (Context.merlin (Super_context.context sctx))
+    (fun () -> dot_merlin sctx ~more_src_dirs ~expander ~dir merlin)
+;;
 
 let more_src_dirs dir_contents ~source_dirs =
   let lib_src_dirs =
     Dir_contents.dirs dir_contents
-    |> List.map ~f:(fun dc ->
-           Path.Build.drop_build_context_exn (Dir_contents.dir dc))
+    |> List.map ~f:(fun dc -> Path.Build.drop_build_context_exn (Dir_contents.dir dc))
   in
   List.rev_append source_dirs lib_src_dirs
+;;
 
 include Unprocessed
