@@ -7,7 +7,6 @@ open Import
 type t
 
 val root : t -> Path.Build.t
-
 val project : t -> Dune_project.t
 
 (** Return the library database associated to this scope *)
@@ -18,9 +17,7 @@ val coq_libs : t -> Coq_lib.DB.t Memo.t
 (** Scope databases *)
 module DB : sig
   val find_by_dir : Path.Build.t -> t Memo.t
-
   val find_by_project : Context.t -> Dune_project.t -> t Memo.t
-
   val public_libs : Context.t -> Lib.DB.t Memo.t
 
   module Lib_entry : sig
@@ -29,8 +26,6 @@ module DB : sig
       | Deprecated_library_name of Dune_file.Deprecated_library_name.t
   end
 
-  val lib_entries_of_package :
-    Context.t -> Package.Name.t -> Lib_entry.t list Memo.t
-
+  val lib_entries_of_package : Context.t -> Package.Name.t -> Lib_entry.t list Memo.t
   val with_all : Context.t -> f:((Dune_project.t -> t) -> 'a) -> 'a Memo.t
 end
