@@ -20,10 +20,11 @@ let xdg =
     (let env_map =
        Env.update Env.initial ~var:"HOME" ~f:(function
          | Some _ as s -> s
-         | None -> (
+         | None ->
            let uid = Unix.getuid () in
-           match Unix.getpwuid uid with
-           | exception Not_found -> None
-           | s -> Some s.pw_dir))
+           (match Unix.getpwuid uid with
+            | exception Not_found -> None
+            | s -> Some s.pw_dir))
      in
      Xdg.create ~env:(Env.get env_map) ())
+;;
